#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-canon-lbp5050"
PACKAGE_VERSION="2.0.1"
PRINTER_NAME=( "Canon LBP5050" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
echo 2 > "$CONTAINER_PATH/DriverType.log"
